'use client';

import Link from 'next/link';
import { useState } from 'react';

export default function Header() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  return (
    <header className="fixed top-0 w-full bg-white shadow-sm z-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-16">
          {/* Logo */}
          <div className="flex-shrink-0">
            <Link href="/" className="text-2xl font-semibold text-gray-900">
              citizenfor.eu
            </Link>
          </div>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex space-x-8">
            <Link href="/services" className="text-gray-600 hover:text-gray-900">
              Services
            </Link>
            <Link href="/how-it-works" className="text-gray-600 hover:text-gray-900">
              Comment ça marche
            </Link>
            <Link href="/pricing" className="text-gray-600 hover:text-gray-900">
              Tarifs
            </Link>
            <Link href="/resources" className="text-gray-600 hover:text-gray-900">
              Ressources
            </Link>
            <Link href="/contact" className="text-gray-600 hover:text-gray-900">
              Contact
            </Link>
          </nav>

          {/* Language Selector and Auth Buttons */}
          <div className="hidden md:flex items-center space-x-4">
            <select className="text-gray-600 bg-transparent border-none focus:outline-none">
              <option value="fr">FR</option>
              <option value="en">EN</option>
              <option value="es">ES</option>
            </select>
            <Link href="/login" className="text-gray-600 hover:text-gray-900">
              Se connecter
            </Link>
            <Link 
              href="/register" 
              className="bg-blue-600 text-white px-4 py-2 rounded-md hover:bg-blue-700 transition-colors"
            >
              S'inscrire
            </Link>
          </div>

          {/* Mobile menu button */}
          <div className="md:hidden">
            <button
              onClick={() => setIsMenuOpen(!isMenuOpen)}
              className="text-gray-600 hover:text-gray-900"
            >
              <svg
                className="h-6 w-6"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                {isMenuOpen ? (
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth={2}
                    d="M6 18L18 6M6 6l12 12"
                  />
                ) : (
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth={2}
                    d="M4 6h16M4 12h16M4 18h16"
                  />
                )}
              </svg>
            </button>
          </div>
        </div>

        {/* Mobile Navigation */}
        {isMenuOpen && (
          <div className="md:hidden">
            <div className="px-2 pt-2 pb-3 space-y-1">
              <Link href="/services" className="block px-3 py-2 text-gray-600 hover:text-gray-900">
                Services
              </Link>
              <Link href="/how-it-works" className="block px-3 py-2 text-gray-600 hover:text-gray-900">
                Comment ça marche
              </Link>
              <Link href="/pricing" className="block px-3 py-2 text-gray-600 hover:text-gray-900">
                Tarifs
              </Link>
              <Link href="/resources" className="block px-3 py-2 text-gray-600 hover:text-gray-900">
                Ressources
              </Link>
              <Link href="/contact" className="block px-3 py-2 text-gray-600 hover:text-gray-900">
                Contact
              </Link>
              <div className="pt-4 pb-3 border-t border-gray-200">
                <div className="flex items-center px-4">
                  <select className="text-gray-600 bg-transparent border-none focus:outline-none">
                    <option value="fr">FR</option>
                    <option value="en">EN</option>
                    <option value="es">ES</option>
                  </select>
                </div>
                <div className="mt-3 space-y-1">
                  <Link href="/login" className="block px-4 py-2 text-gray-600 hover:text-gray-900">
                    Se connecter
                  </Link>
                  <Link 
                    href="/register" 
                    className="block px-4 py-2 text-blue-600 hover:text-blue-700"
                  >
                    S'inscrire
                  </Link>
                </div>
              </div>
            </div>
          </div>
        )}
      </div>
    </header>
  );
} 