import Image from "next/image";
import Link from "next/link";
import FaqAccordion from "./components/FaqAccordion";

export default function Home() {
  const services = [
    {
      title: "Numéro Fiscal Français (NIF)",
      description: "Simplifiez l'obtention de votre identifiant fiscal indispensable pour vivre et travailler en France.",
      icon: (
        <svg className="w-8 h-8" fill="none" viewBox="0 0 24 24" stroke="currentColor">
          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={1.5} d="M9 12h6m-6 4h6m2 5H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
        </svg>
      ),
      href: "/services/nif",
      isAvailable: true
    },
    {
      title: "Sécurité Sociale Française",
      description: "Accédez au système de santé français grâce à notre guide pas à pas pour votre affiliation.",
      icon: (
        <svg className="w-8 h-8" fill="none" viewBox="0 0 24 24" stroke="currentColor">
          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={1.5} d="M9 12l2 2 4-4m5.618-4.016A11.955 11.955 0 0112 2.944a11.955 11.955 0 01-8.618 3.04A12.02 12.02 0 003 9c0 5.591 3.824 10.29 9 11.622 5.176-1.332 9-6.03 9-11.622 0-1.042-.133-2.052-.382-3.016z" />
        </svg>
      ),
      href: "/services/securite-sociale",
      isAvailable: true
    },
    {
      title: "Compte Bancaire Français",
      description: "Guides et conseils pour ouvrir un compte bancaire en France, adapté à votre situation.",
      icon: (
        <svg className="w-8 h-8" fill="none" viewBox="0 0 24 24" stroke="currentColor">
          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={1.5} d="M3 6l2-2h14l2 2M5 20h14a2 2 0 002-2V8a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2zM12 9v6m-3-3h6" />
        </svg>
      ),
      href: "/services/compte-bancaire",
      isAvailable: false
    },
    {
      title: "Visas, Documents & Formalités",
      description: "Informations clés sur les visas, checklists de documents essentiels, et aide pour d'autres démarches.",
      icon: (
        <svg className="w-8 h-8" fill="none" viewBox="0 0 24 24" stroke="currentColor">
          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={1.5} d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
        </svg>
      ),
      href: "/services/documents",
      isAvailable: true
    }
  ];

  return (
    <div className="flex flex-col">
      {/* Hero Section */}
      <section className="relative h-[600px] bg-gradient-to-r from-blue-600 to-blue-800">
        <div className="absolute inset-0">
          <Image
            src="/hero-bg.jpg"
            alt="Hero background"
            fill
            className="object-cover opacity-20"
            priority
          />
        </div>
        <div className="relative container mx-auto px-4 h-full flex flex-col justify-center">
          <h1 className="text-5xl font-bold text-white mb-6">
            Simplifiez vos démarches administratives en France
          </h1>
          <p className="text-xl text-white mb-8 max-w-2xl">
            CitizenFor vous accompagne dans toutes vos démarches d'installation en France.
            Un service personnalisé et efficace pour vous faciliter la vie.
          </p>
          <div className="flex gap-4">
            <Link
              href="/services"
              className="bg-white text-blue-600 px-8 py-3 rounded-lg font-semibold hover:bg-blue-50 transition-colors"
            >
              Découvrir nos services
            </Link>
            <Link
              href="/contact"
              className="bg-transparent border-2 border-white text-white px-8 py-3 rounded-lg font-semibold hover:bg-white/10 transition-colors"
            >
              Nous contacter
            </Link>
          </div>
        </div>
      </section>

      {/* Services Section */}
      <section className="py-20 bg-[#f5f5f7]">
        <div className="container mx-auto px-4">
          <h2 className="text-4xl font-semibold text-center mb-4 text-gray-900">
            Nos Services pour une Installation Réussie
          </h2>
          <p className="text-xl text-center mb-16 max-w-2xl mx-auto text-gray-500">
            Des solutions simples et efficaces pour vos démarches essentielles en France.
          </p>
          <div className="grid grid-cols-1 md:grid-cols-2 gap-8 max-w-6xl mx-auto">
            {services.map((service, index) => (
              <div
                key={index}
                className="group bg-white rounded-2xl p-8 transition-all duration-300 hover:scale-[1.02] hover:shadow-[0_8px_16px_rgb(0,0,0,0.1)] relative overflow-hidden"
              >
                {/* Service Icon */}
                <div className="mb-6">
                  <div className="w-12 h-12 rounded-full bg-blue-50 flex items-center justify-center text-blue-600">
                    {service.icon}
                  </div>
                </div>

                {/* Service Content */}
                <div className="space-y-4">
                  <h3 className="text-2xl font-semibold text-gray-900 flex items-center gap-3">
                    {service.title}
                    {!service.isAvailable && (
                      <span className="text-sm font-medium text-blue-600 bg-blue-50 px-3 py-1 rounded-full">
                        Prochainement
                      </span>
                    )}
                  </h3>
                  <p className="text-gray-500 text-lg leading-relaxed">
                    {service.description}
                  </p>
                  <Link
                    href={service.href}
                    className={`inline-flex items-center text-base font-medium mt-4 ${
                      service.isAvailable 
                        ? "text-blue-600 hover:text-blue-700"
                        : "text-gray-400 cursor-not-allowed"
                    }`}
                  >
                    En savoir plus
                    <svg 
                      className={`w-5 h-5 ml-2 transition-transform duration-300 ${
                        service.isAvailable ? "group-hover:translate-x-1" : ""
                      }`} 
                      fill="none" 
                      stroke="currentColor" 
                      viewBox="0 0 24 24"
                    >
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
                    </svg>
                  </Link>
                </div>

                {/* Background Gradient Effect */}
                <div className="absolute inset-0 bg-gradient-to-br from-transparent to-gray-50/50 pointer-events-none" />
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* Avantages Section */}
      <section className="py-20 bg-gradient-to-br from-blue-50 to-white">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-4 text-gray-900">Pourquoi choisir CitizenFor ?</h2>
          <p className="text-gray-700 text-center mb-12 max-w-2xl mx-auto">
            Notre plateforme vous offre une expérience unique et des avantages exclusifs pour faciliter votre installation en France.
          </p>
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {[
              {
                title: 'Gain de temps',
                description: 'Économisez des heures précieuses grâce à notre expertise et nos processus optimisés.',
                icon: '⏱️',
              },
              {
                title: 'Experts qualifiés',
                description: 'Une équipe de professionnels expérimentés à votre service.',
                icon: '👨‍💼',
              },
              {
                title: 'Suivi personnalisé',
                description: 'Un accompagnement sur mesure adapté à votre situation unique.',
                icon: '🎯',
              },
              {
                title: 'Support multilingue',
                description: 'Communication disponible en français, anglais et espagnol.',
                icon: '🌍',
              },
              {
                title: 'Processus simplifié',
                description: 'Des démarches claires et structurées pour votre tranquillité.',
                icon: '✨',
              },
              {
                title: 'Satisfaction garantie',
                description: 'Un engagement fort pour votre réussite et votre satisfaction.',
                icon: '🤝',
              },
            ].map((advantage, index) => (
              <div
                key={index}
                className="bg-white p-6 rounded-xl shadow-sm hover:shadow-md transition-shadow"
              >
                <div className="text-4xl mb-4">{advantage.icon}</div>
                <h3 className="text-xl font-semibold mb-2 text-gray-900">{advantage.title}</h3>
                <p className="text-gray-700">{advantage.description}</p>
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* How it works Section */}
      <section className="py-20 bg-gray-50">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-12 text-gray-900">Comment ça marche ?</h2>
          <div className="grid grid-cols-1 md:grid-cols-4 gap-8">
            {[
              {
                step: '1',
                title: 'Contactez-nous',
                description: 'Prenez rendez-vous pour une première consultation.',
              },
              {
                step: '2',
                title: 'Analyse de votre situation',
                description: 'Nous étudions vos besoins et votre situation.',
              },
              {
                step: '3',
                title: 'Proposition de service',
                description: 'Nous vous proposons un accompagnement sur mesure.',
              },
              {
                step: '4',
                title: 'Accompagnement',
                description: 'Nous vous guidons tout au long du processus.',
              },
            ].map((step, index) => (
              <div
                key={index}
                className="text-center"
              >
                <div className="w-12 h-12 bg-blue-600 text-white rounded-full flex items-center justify-center text-xl font-bold mx-auto mb-4">
                  {step.step}
                </div>
                <h3 className="text-xl font-semibold mb-2 text-gray-900">{step.title}</h3>
                <p className="text-gray-700">{step.description}</p>
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section className="py-20 bg-white">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-4 text-gray-900">Questions fréquentes</h2>
          <p className="text-gray-700 text-center mb-12 max-w-2xl mx-auto">
            Trouvez rapidement des réponses à vos questions les plus courantes sur nos services.
          </p>
          <div className="max-w-3xl mx-auto">
            {[
              {
                question: "Combien de temps prennent les démarches administratives ?",
                answer: "Les délais varient selon la démarche. Notre rôle est de réduire ces délais au minimum en vous aidant à constituer un dossier complet et conforme dès le premier envoi. Nous vous donnons une estimation précise des délais pour chaque procédure."
              },
              {
                question: "Quelles sont les langues disponibles pour vos services ?",
                answer: "Nous proposons nos services en français, anglais et espagnol. Nos experts sont multilingues et peuvent vous accompagner dans la langue de votre choix."
              },
              {
                question: "Comment se déroule le premier rendez-vous ?",
                answer: "Le premier rendez-vous est une consultation en visioconférence de 30 minutes. Nous évaluons ensemble vos besoins, répondons à vos questions et établissons un plan d'action personnalisé."
              },
              {
                question: "Quels sont vos tarifs ?",
                answer: "Nos tarifs varient selon les services et le niveau d'accompagnement souhaité. Nous proposons des forfaits adaptés à chaque situation. Consultez notre page Tarifs pour plus de détails."
              }
            ].map((faq, index) => (
              <FaqAccordion key={index} question={faq.question} answer={faq.answer} />
            ))}
          </div>
          <div className="text-center mt-8">
            <Link
              href="/faq"
              className="text-blue-600 hover:text-blue-700 font-semibold inline-flex items-center"
            >
              Voir toutes les questions
              <svg className="w-5 h-5 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
              </svg>
            </Link>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-20 bg-blue-600 text-white">
        <div className="container mx-auto px-4 text-center">
          <h2 className="text-3xl font-bold mb-6">Prêt à commencer ?</h2>
          <p className="text-xl mb-8 max-w-2xl mx-auto">
            Contactez-nous dès maintenant pour un accompagnement personnalisé.
          </p>
          <Link
            href="/contact"
            className="bg-white text-blue-600 px-8 py-3 rounded-lg font-semibold hover:bg-blue-50 transition-colors inline-block"
          >
            Prendre rendez-vous
          </Link>
        </div>
      </section>
    </div>
  );
}
